﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using C1.WPF.DataGrid;
using C1.WPF.DataGrid.Summaries;

namespace DataGrid_CustomGrouping
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            c1DataGrid1.Loaded +=c1DataGrid1_Loaded;
            c1DataGrid1.ItemsSource = CreateSampleData();

            // grouping with summaries behavior (ALREADY SET IN XAML)
            //C1GroupingWithSummariesBehavior.SetGroupingWithSummariesBehavior(c1DataGrid1, new C1GroupingWithSummariesBehavior());
        }

        void c1DataGrid1_Loaded(object sender, RoutedEventArgs e)
        {
            // set group converters (ALREADY SET IN XAML)
            //c1DataGrid1.Columns["Received"].GroupConverter = new MyDateGroupConverter();
            //c1DataGrid1.Columns["Received"].GroupContentConverter = new MyDateGroupContentConverter();
            

            // group by a column
            c1DataGrid1.GroupBy(c1DataGrid1.Columns["Received"], DataGridSortDirection.Descending);

            // display summary information for 'Size' column (ALREADY SET IN XAML)
            //DataGridAggregate.SetAggregateFunctions(c1DataGrid1.Columns["Size"], new DataGridAggregatesCollection { new DataGridAggregateSum() });
        }

        List<MailItem> CreateSampleData()
        {
            List<MailItem> items = new List<MailItem>();
            Random rnd = new Random();
            string[] names = { "Ben Schorr", "Chris Brown", "Richard Mosher", "Michael Flatley", "Ken Slovak", "Greg Lutz", "Kris Kringle", "Kevin", "Larry Seltzer", "Rob M. Smith" };
            string[] subjects = { "Re: Alert - Microsoft Exchange", "Re: Destination folder", "Re: Repeating Controls", "Sync Issues Reference?", "Are you able to attend tomorrow?", "Create a service from Webinar series", "Re: Modify the IE toolbar", "Re: Sync Issues Reference?", "Re: Update on Bugs reported in TFS" };
            for (int i = 0; i < 70; i++)
            {
                MailItem item = new MailItem();
                item.Subject = subjects[rnd.Next(subjects.Length - 1)];
                item.Received = DateTime.Now.Subtract(new TimeSpan(rnd.Next(100), rnd.Next(60), 0));
                int r = rnd.Next(3);
                if (r == 1)
                {
                    item.Read = true;
                }
                else if (r == 2)
                {
                    item.Read = false;
                }
                else
                {
                    item.Read = null;
                }
                item.From = names[rnd.Next(names.Length - 1)];
                item.Size = rnd.Next(2000);
                item.Flagged = rnd.Next(5) % 2 == 0 ? false : true;
                items.Add(item);
            }
            return items;
        }
    }

    public class MyDateGroupConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            DateTime date = (DateTime)value;
            if(date.DayOfYear == DateTime.Now.DayOfYear)
            {
                return "Date: Today";
            }
            else if (date.DayOfYear == DateTime.Now.DayOfYear - 1)
            {
                return "Date: Yesterday";
            }
            else
            {
                return "Date: Older";
            }
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }
    }

    /// <summary>
    /// Used to convert the UI of grouped rows. Nothing converted in this demo
    /// </summary>
    public class MyDateGroupContentConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            // just simple string, no conversion needed
            return value;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }
    }

    /// <summary>
    /// Used to convert bytes (double) to a readable string, ie: 20KB
    /// </summary>
    public class MyFileSizeConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return String.Format("{0:N2} KB", ((double)value) / 1024);
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }
    }

    /// <summary>
    /// Used to convert bytes (double) to a readable string, ie: 20KB
    /// </summary>
    public class ReadIconConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            bool? read = (bool?)value;
            if(read == true)
            {
                return new BitmapImage(new Uri("/Resources/Mail-Read.png", UriKind.Relative));
            }
            else if(read == false)
            {
                return new BitmapImage(new Uri("/Resources/Mail.png", UriKind.Relative));
            }
            else
            {
                return new BitmapImage(new Uri("/Resources/Mail-Reply.png", UriKind.Relative));
            }
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            return value;
        }
    }

    public class MailItem
    {
        public string From { get; set; }
        public string Subject { get; set; }
        public DateTime Received { get; set; }
        public double Size { get; set; }
        public bool? Read { get; set; }
        public bool Flagged { get; set; }

    }
}
